/*
VDS.Web.Server is licensed under the MIT License

Copyright (c) 2010-2013 Robert Vesse

Permission is hereby granted, free of charge, to any person obtaining a copy of this software
and associated documentation files (the "Software"), to deal in the Software without restriction,
including without limitation the rights to use, copy, modify, merge, publish, distribute,
sublicense, and/or sell copies of the Software, and to permit persons to whom the Software 
is furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all copies or
substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING
BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND 
NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, 
DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, 
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
*/

using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;

namespace VDS.Web.Logging
{
    /// <summary>
    /// A Logger which logs errors to the Console
    /// </summary>
    public class ConsoleErrorLogger 
        : IExtendedHttpLogger
    {
        /// <summary>
        /// Logs an error
        /// </summary>
        /// <param name="ex">Error</param>
        public void LogError(Exception ex)
        {
            Console.Error.WriteLine(ex.Message);
            Console.Error.WriteLine(ex.StackTrace);
            if (ex.InnerException != null)
            {
                Console.Error.WriteLine();
                Console.Error.WriteLine("Inner Exception:");
                this.LogError(ex.InnerException);
            }
        }

        /// <summary>
        /// Logs a request
        /// </summary>
        /// <param name="context">Server Context</param>
        public void LogRequest(HttpServerContext context)
        {
            //Does Nothing
        }

        /// <summary>
        /// Handles the server pre-state change notification
        /// </summary>
        /// <param name="server">HTTP Server</param>
        /// <param name="target">State being transitioned to</param>
        public virtual void PreStateChange(HttpServer server, ServerState target)
        {
            //Nothing to do
        }

        /// <summary>
        /// Handles the server post-state change notification
        /// </summary>
        /// <param name="server">HTTP Server</param>
        public virtual void PostStateChange(HttpServer server)
        {
            //Nothing to do
        }

        /// <summary>
        /// Disposes of the Logger
        /// </summary>
        public void Dispose()
        {
            //Nothing to do
        }
    }
}
