/*
VDS.Web.Server is licensed under the MIT License

Copyright (c) 2010-2013 Robert Vesse

Permission is hereby granted, free of charge, to any person obtaining a copy of this software
and associated documentation files (the "Software"), to deal in the Software without restriction,
including without limitation the rights to use, copy, modify, merge, publish, distribute,
sublicense, and/or sell copies of the Software, and to permit persons to whom the Software 
is furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all copies or
substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING
BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND 
NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, 
DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, 
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
*/

using System;
using VDS.Web.Logging;

namespace VDS.Web.Modules
{
    /// <summary>
    /// Module using to perform request logging
    /// </summary>
    public sealed class LoggingModule
        : IHttpListenerModule
    {
        /// <summary>
        /// Process a request by asking each logger registered on the server to log it
        /// </summary>
        /// <param name="context">Server Context</param>
        /// <returns></returns>
        public bool ProcessRequest(HttpServerContext context)
        {
            foreach (IHttpLogger logger in context.Server.Loggers)
            {
                try
                {
                    logger.LogRequest(context);
                }
                catch (Exception ex)
                {
                    context.Server.LogErrors(ex);
                }
            }

            //Logging Module always returns true to allow other Modules to execute
            return true;
        }

        /// <summary>
        /// Handles the server pre-state change notification
        /// </summary>
        /// <param name="server">HTTP Server</param>
        /// <param name="target">State the server is transitioning to</param>
        public void PreStateChange(HttpServer server, ServerState target)
        {
            foreach (IHttpLogger logger in server.Loggers)
            {
                logger.PreStateChange(server, target);
            }
        }

        /// <summary>
        /// Handles the server post-state change notification
        /// </summary>
        /// <param name="server">HTTP Server</param>
        public void PostStateChange(HttpServer server)
        {
            foreach (IHttpLogger logger in server.Loggers)
            {
                logger.PostStateChange(server);
            }
        }

        /// <summary>
        /// Diposes of the module
        /// </summary>
        public void Dispose()
        {
            //Nothing to do
        }
    }
}
